summaryrefslogtreecommitdiffstats
path: root/src/extension/effect.h
diff options
context:
space:
mode:
authorbulia byak <buliabyak@gmail.com>2009-02-10 06:35:55 +0000
committerbuliabyak <buliabyak@users.sourceforge.net>2009-02-10 06:35:55 +0000
commit5143d7a8ae2647e2fff72018a7377cf160ec5580 (patch)
tree12a041884becbe13ee4b4663c81d7819a5db080f /src/extension/effect.h
parentSplit off first portion of icons into separate files to begin working on (diff)
downloadinkscape-5143d7a8ae2647e2fff72018a7377cf160ec5580.tar.gz
inkscape-5143d7a8ae2647e2fff72018a7377cf160ec5580.zip
Filters, Extensions menus
(bzr r7259)
Diffstat (limited to 'src/extension/effect.h')
-rw-r--r--src/extension/effect.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/extension/effect.h b/src/extension/effect.h
index 0724bd961..c02ce542b 100644
--- a/src/extension/effect.h
+++ b/src/extension/effect.h
@@ -40,11 +40,12 @@ class Effect : public Extension {
/** \brief This is the last effect that was used. This is used in
a menu item to rapidly recall the same effect. */
static Effect * _last_effect;
/** \brief The location of the effects menu on the menu structure
XML file. This is saved so it only has to be discovered
once. */
static Inkscape::XML::Node * _effects_list;
- bool find_effects_list (Inkscape::XML::Node * menustruct);
+ static Inkscape::XML::Node * _filters_list;
+ Inkscape::XML::Node *find_menu (Inkscape::XML::Node * menustruct, const gchar *name);
void merge_menu (Inkscape::XML::Node * base, Inkscape::XML::Node * start, Inkscape::XML::Node * patern, Inkscape::XML::Node * mergee);
/** \brief This is the verb type that is used for all effect's verbs.
@@ -40,11 +40,12 @@ class Effect : public Extension {
a menu item to rapidly recall the same effect. */
static Effect * _last_effect;
- /** \brief The location of the effects menu on the menu structure
+ /** \brief The location of the Extensions and Filters menus on the menu structure
XML file. This is saved so it only has to be discovered
once. */